@@ -19,7 +19,12 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 ================================================================================
+	The Instrument class is pretty self explanatory. Instruments can be used
+	with Tracks to define which instrument plays what, with the added bonus
+	of tracking whether the entered notes are in the range of the instrument.
 
+	It's probably easiest to subclass your own Instruments (see Piano and 
+	Guitar for examples)
 
 ================================================================================
 
@@ -31,12 +36,14 @@ class Instrument:
 
 	name = 'Instrument'
 	range = (Note('C', 0),  Note('C', 8))
-	clef = 'bass and treble'
+	clef = 'piano'
 
 	def __init__(self):
 		pass
 
 	def set_range(self, range):
+		"""Sets the range of the instrument. A range is a tuple 
+		of two Notes."""
 		self.range = range
 
 	def note_in_range(self, note):
@@ -47,11 +54,17 @@ class Instrument:
 		return False
 
 	def can_play_notes(self, notes):
+		"""Will test if the notes lie within the range of the 
+		instrument. Returns True if so, False otherwise."""
 		for n in notes:
 			if not(self.note_in_range(n)):
 				return False
 		return True
 
+	def __repr__(self):
+		"""A string representation of the object"""
+		return "%s [%s - %s]" % (self.name, self.range[0], self.range[1])
+
 class Piano(Instrument):
 	
 	name = 'Piano'
